Struct Capability
pub struct Capability(/* private fields */);wayland and Linux only.Expand description
seat capability bitmask
This is a bitmask of capabilities this seat has; if a member is set, then it is present on the seat.
Implementations
impl Capability
impl Capability
pub const Pointer: Capability
pub const Pointer: Capability
the seat has pointer devices
pub const Keyboard: Capability
pub const Keyboard: Capability
the seat has one or more keyboards
pub const Touch: Capability
pub const Touch: Capability
the seat has touch devices
impl Capability
impl Capability
pub const fn empty() -> Capability
pub const fn empty() -> Capability
Get a flags value with all bits unset.
pub const fn all() -> Capability
pub const fn all() -> Capability
Get a flags value with all known bits set.
pub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<Capability>
pub const fn from_bits(bits: u32) -> Option<Capability>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> Capability
pub const fn from_bits_truncate(bits: u32) -> Capability
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> Capability
pub const fn from_bits_retain(bits: u32) -> Capability
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<Capability>
pub fn from_name(name: &str) -> Option<Capability>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: Capability) -> bool
pub const fn intersects(&self, other: Capability) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: Capability) -> bool
pub const fn contains(&self, other: Capability) -> bool
Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: Capability)
pub fn insert(&mut self, other: Capability)
The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: Capability)
pub fn remove(&mut self, other: Capability)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: Capability)
pub fn toggle(&mut self, other: Capability)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: Capability, value: bool)
pub fn set(&mut self, other: Capability, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: Capability) -> Capability
pub const fn intersection(self, other: Capability) -> Capability
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: Capability) -> Capability
pub const fn union(self, other: Capability) -> Capability
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: Capability) -> Capability
pub const fn difference(self, other: Capability) -> Capability
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: Capability) -> Capability
pub const fn symmetric_difference(self, other: Capability) -> Capability
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> Capability
pub const fn complement(self) -> Capability
The bitwise negation (!) of the bits in self, truncating the result.
impl Capability
impl Capability
pub const fn iter(&self) -> Iter<Capability>
pub const fn iter(&self) -> Iter<Capability>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<Capability>
pub const fn iter_names(&self) -> IterNames<Capability>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.