Struct WlSeat
pub struct WlSeat { /* private fields */ }wayland and Linux only.Expand description
group of input devices
A seat is a group of keyboards, pointer and touch devices. This object is published as a global during start up, or when such a device is hot plugged. A seat typically has a pointer and maintains a keyboard focus and a pointer focus.
See also the Event enum for this interface.
Implementations
impl WlSeat
impl WlSeat
pub fn get_pointer<U, D>(&self, qh: &QueueHandle<D>, udata: U) -> WlPointer
pub fn get_pointer<U, D>(&self, qh: &QueueHandle<D>, udata: U) -> WlPointer
return pointer object
The ID provided will be initialized to the wl_pointer interface for this seat.
This request only takes effect if the seat has the pointer capability, or has had the pointer capability in the past. It is a protocol violation to issue this request on a seat that has never had the pointer capability. The missing_capability error will be sent in this case.
pub fn get_keyboard<U, D>(&self, qh: &QueueHandle<D>, udata: U) -> WlKeyboard
pub fn get_keyboard<U, D>(&self, qh: &QueueHandle<D>, udata: U) -> WlKeyboard
return keyboard object
The ID provided will be initialized to the wl_keyboard interface for this seat.
This request only takes effect if the seat has the keyboard capability, or has had the keyboard capability in the past. It is a protocol violation to issue this request on a seat that has never had the keyboard capability. The missing_capability error will be sent in this case.
pub fn get_touch<U, D>(&self, qh: &QueueHandle<D>, udata: U) -> WlTouch
pub fn get_touch<U, D>(&self, qh: &QueueHandle<D>, udata: U) -> WlTouch
return touch object
The ID provided will be initialized to the wl_touch interface for this seat.
This request only takes effect if the seat has the touch capability, or has had the touch capability in the past. It is a protocol violation to issue this request on a seat that has never had the touch capability. The missing_capability error will be sent in this case.
pub fn release(&self)
pub fn release(&self)
release the seat object
Using this request a client can tell the server that it is not going to use the seat object anymore.